@@ -1,20 +1,10 @@
-from os import popen as os_popen, getuid as os_getuid
-from snakypy import printer
 from re import search as re_search
-from zshpower.config import package
-from zshpower import __version__
-from re import M as re_m
 from snakypy.ansi import FG, NONE
-from docopt import docopt
-from zshpower.config import menu
-
-try:
-    import pwd
-except ImportError:
-    pass
 
 
 def read_zshrc(zshrc):
+    from snakypy import printer
+
     try:
         with open(zshrc) as f:
             return f.read()
@@ -23,6 +13,11 @@ def read_zshrc(zshrc):
 
 
 def arguments(argv=None):
+    from zshpower.config import menu
+    from docopt import docopt
+    from zshpower import __version__
+    from zshpower.config import package
+
     formatted_version = f"{package.info['name']} version: {FG.CYAN}{__version__}{NONE}"
     data = docopt(menu.options, argv=argv, version=formatted_version)
     return data
@@ -41,17 +36,28 @@ def read_zshrc_omz(zshrc):
 
 
 def current_shell():
-    pw = pwd.getpwuid(os_getuid())
+    from os import getuid
+
+    try:
+        import pwd
+    except ImportError:
+        pass
+
+    pw = pwd.getpwuid(getuid())
     path_shell = pw[-1]
     shell = str(path_shell).split("/")[-1]
     return shell, path_shell
 
 
 def current_user():
-    return str(os_popen("whoami").read()).replace("\n", "")
+    from os import popen
+
+    return str(popen("whoami").read()).replace("\n", "")
 
 
 def plugins_current_zshrc(zshrc):
+    from re import M as re_m
+
     current_zshrc = read_zshrc(zshrc)
     m = re_search(r"^plugins=\(.*", current_zshrc, flags=re_m)
     if m is not None:
